Index: kernel/generic/src/mm/backend_anon.c
===================================================================
--- kernel/generic/src/mm/backend_anon.c	(revision 9a9c805be5fb4f2fa097947afcec03940ca593f8)
+++ kernel/generic/src/mm/backend_anon.c	(revision 5892ec112c8c6043d7d13d3ec78ccfca8d0f278f)
@@ -74,5 +74,5 @@
 bool anon_create(as_area_t *area)
 {
-	if (area->flags & AS_AREA_NORESERVE)
+	if (area->flags & AS_AREA_LATE_RESERVE)
 		return true;
 
@@ -82,5 +82,5 @@
 bool anon_resize(as_area_t *area, size_t new_pages)
 {
-	if (area->flags & AS_AREA_NORESERVE)
+	if (area->flags & AS_AREA_LATE_RESERVE)
 		return true;
 
@@ -106,5 +106,5 @@
 	ASSERT(mutex_locked(&area->as->lock));
 	ASSERT(mutex_locked(&area->lock));
-	ASSERT(!(area->flags & AS_AREA_NORESERVE));
+	ASSERT(!(area->flags & AS_AREA_LATE_RESERVE));
 
 	/*
@@ -146,5 +146,5 @@
 void anon_destroy(as_area_t *area)
 {
-	if (area->flags & AS_AREA_NORESERVE)
+	if (area->flags & AS_AREA_LATE_RESERVE)
 		return;
 
@@ -236,5 +236,5 @@
 		 */
 
-		if (area->flags & AS_AREA_NORESERVE) {
+		if (area->flags & AS_AREA_LATE_RESERVE) {
 			/*
 			 * Reserve the memory for this page now.
@@ -274,9 +274,9 @@
 	ASSERT(mutex_locked(&area->lock));
 
-	if (area->flags & AS_AREA_NORESERVE) {
-		/*
-		 * In case of the NORESERVE areas, physical memory will not be
-		 * unreserved when the area is destroyed so we need to use the
-		 * normal unreserving frame_free().
+	if (area->flags & AS_AREA_LATE_RESERVE) {
+		/*
+		 * In case of the late reserve areas, physical memory will not
+		 * be unreserved when the area is destroyed so we need to use
+		 * the normal unreserving frame_free().
 		 */
 		frame_free(frame);
